@@ -12,16 +12,16 @@
  *	for default icon set (Glance)
  *
  * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
+ * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU weather-config.h General Public
  * License along with this software; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
@@ -109,7 +109,7 @@
 #define REGIONSFILE         "regions.list"
 #define LOCATIONSFILE       "locations.list"
 #define ICONS_PATH          "/usr/share/omweather/icons/"
-#define BUTTON_ICONS		"/usr/share/omweather/button_icons/"
+#define BUTTON_ICONS        "/usr/share/omweather/button_icons/"
 #define IMAGES_PATH         "/usr/share/omweather/images/"
 
  #define START_FUNCTION        fprintf(stderr,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);
@@ -345,8 +345,9 @@ typedef struct applet_config{
     gboolean	update_gsm;
     gboolean	update_wlan;
     gboolean	animation;
-    gint	view_mode;
+    gint        view_mode;
     gint        scale_in_popup;
+    gchar       *mod;
 }AppletConfig;
 /*******************************************************************************/
 #if defined CLUTTER || defined OS2009
