@@ -146,7 +146,8 @@ void create_about_dialog(void){
                "Italian - Pavel Fialko, Alessandro Pasotti,\n"
                "\tSalvatore Fiorenzo, Luca Onnis\n"
                "Spanish - Alejandro Lopez\n"
-               "Polish - Tomasz Dominikowski\n"));
+               "Polish - Tomasz Dominikowski\n"
+               "Slovak - Roman Moravčík"));
 
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
                              create_scrolled_window_with_text(tmp_buff,
