@@ -12,16 +12,16 @@
  *	for default icon set (Glance)
  *
  * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
+ * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU weather-config.h General Public
  * License along with this software; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
@@ -128,7 +128,17 @@ set_font(GtkWidget * widget, const gchar * description, const gint size) {
     END_FUNCTION;
 #endif
 }
+/*******************************************************************************/
+gchar *
+create_presets_image_path(gchar* image){
+    gchar *result;
 
+    result = g_strdup_printf("%s%s/%s", IMAGES_PATH, app->config->mod, image);
+
+    if (access(result, F_OK) != 0)
+        result = g_strdup_printf("%s%s/%s", IMAGES_PATH, "Digia", image);
+    return result;
+}
 /*******************************************************************************/
 void
 set_font_color(GtkWidget * widget, guint16 red, guint16 green,
@@ -753,6 +763,18 @@ write_log(char *string){
     fflush(filelog);
     fclose(filelog);
 #endif
+}
+/*******************************************************************************/
+void
+load_style(void){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+    gchar tmp_buff[2048];
+    snprintf(tmp_buff, sizeof(tmp_buff) - 1, "%s%s/%s", IMAGES_PATH, app->config->mod, "style.rc");
+    gtk_rc_parse(tmp_buff);
+   
 }
 /*******************************************************************************/
 /* Reload omweather's plugin */
